@@ -1,4 +1,4 @@
-import dsv from "./dsv";
+import dsv from "./dsv.js";
 
 var csv = dsv(",");
 
@@ -7,3 +7,5 @@ export var csvParseRows = csv.parseRows;
 export var csvFormat = csv.format;
 export var csvFormatBody = csv.formatBody;
 export var csvFormatRows = csv.formatRows;
+export var csvFormatRow = csv.formatRow;
+export var csvFormatValue = csv.formatValue;
